@@ -1,10 +1,10 @@
-from arkitekt.apps import Arkitekt
 from rekuest.register import register, register_structure, PortGroupInput as group
 from rekuest.actors.reactive.api import log, alog, progress, aprogress
 from .builders import easy, publicqt, jupy, scheduler
+from .apps.types import App
 
 __all__ = [
-    "Arkitekt",
+    "App",
     "register",
     "easy",
     "publicqt",
