@@ -38,56 +38,41 @@ Example:
 """
 
 
-from arkitekt.apps.herre import HerreApp
-from pydantic import Field
 from arkitekt.healthz import FaktsHealthz
 from mikro.datalayer import DataLayer
 from mikro.mikro import Mikro
 from mikro.rath import MikroLinkComposition, MikroRath
 from rath.links.split import SplitLink
 from rath.contrib.fakts.links.aiohttp import FaktsAIOHttpLink
-from rath.contrib.fakts.links.websocket import FaktsWebsocketLink
+from rath.contrib.fakts.links.subscription_transport_ws import FaktsWebsocketLink
 from rath.contrib.herre.links.auth import HerreAuthLink
 from mikro.contrib.fakts.datalayer import FaktsDataLayer
+from mikro.links.datalayer import DataLayerUploadLink
 from graphql import OperationType
+from fakts import Fakts
+from herre import Herre
 
 
 class ArkitektMikro(Mikro):
-    rath: MikroRath = Field(
-        default_factory=lambda: MikroRath(
+    rath: MikroRath
+    datalayer: DataLayer
+    healthz: FaktsHealthz
+
+
+def build_arkitekt_mikro(herre: Herre, fakts: Fakts):
+    layer = FaktsDataLayer(fakts_group="minio", fakts=fakts, herre=herre)
+    return ArkitektMikro(
+        rath=MikroRath(
             link=MikroLinkComposition(
-                auth=HerreAuthLink(),
+                auth=HerreAuthLink(herre=herre),
                 split=SplitLink(
-                    left=FaktsAIOHttpLink(fakts_group="mikro"),
-                    right=FaktsWebsocketLink(fakts_group="mikro"),
+                    left=FaktsAIOHttpLink(fakts_group="mikro", fakts=fakts),
+                    right=FaktsWebsocketLink(fakts_group="mikro", fakts=fakts),
                     split=lambda o: o.node.operation != OperationType.SUBSCRIPTION,
                 ),
+                datalayer=DataLayerUploadLink(datalayer=layer),
             )
-        )
+        ),
+        datalayer=layer,
+        healthz=FaktsHealthz(fakts_group="mikro", fakts=fakts),
     )
-    datalayer: DataLayer = Field(
-        default_factory=lambda: FaktsDataLayer(fakts_group="minio")
-    )
-    healthz: FaktsHealthz = Field(
-        default_factory=lambda: FaktsHealthz(fakts_group="mikro")
-    )
-
-
-class MikroApp(HerreApp):
-    """Mikro App
-
-    It is responsible for setting up the connection to the mikro-server and
-    handling authentification and setting up the configuration. Mikro handles the creation of the datalayer and
-    the graphql client.
-
-    You can compose this app together with other apps to create a full fledged app. (Like combining with
-    arkitekt to enable to call functions that you define on the app). See the example in the docstring.
-
-    Attributes:
-        fakts (Fakts): The fakts instance to use.
-        mikro (Mikro): The mikro instance to use.
-        herre (Herre): The herre instance to use.
-
-    """
-
-    mikro: ArkitektMikro = Field(default_factory=ArkitektMikro)
