@@ -87,7 +87,7 @@ def generate_deployment(
     definitions = generate_definitions("app") if with_definitions else []
 
     deployment = Deployment(
-        **manifest.dict(),
+        **manifest.dict(exclude={"command"}),
         definitions=definitions,
         image=image,
         command=command or manifest.command,
