@@ -1,6 +1,6 @@
 from importlib import import_module, reload
 import asyncio
-from arkitekt import Arkitekt
+from arkitekt import App
 from watchfiles import awatch
 from rich.panel import Panel
 from watchfiles.filters import PythonFilter
@@ -15,7 +15,7 @@ from arkitekt.cli.utils import import_builder
 from .types import Manifest
 
 
-async def build_and_run(app):
+async def build_and_run(app: App):
     async with app:
         await app.rekuest.run()
 
@@ -139,7 +139,7 @@ async def dev_module(
                 console.print(panel)
 
     try:
-        app: Arkitekt = builder_func(
+        app: App = builder_func(
             identifier,
             version=version,
             url=url,
@@ -223,7 +223,7 @@ async def dev_module(
             continue
 
         try:
-            app: Arkitekt = builder_func(
+            app: App = builder_func(
                 identifier,
                 version=version,
                 url=url,
