@@ -466,8 +466,9 @@ def search_username_in_docker_info(docker_info: str):
 
 @cli.command()
 @click.option("--build", help="The build to use", type=str, default="latest")
+@click.option("--command", help="Overwrite the used command", type=str, required=False)
 @click.option("--tag", help="The tag to use")
-def publish(build, tag):
+def publish(build, tag, command):
     """Deploys the arkitekt app to port"""
 
     from arkitekt.cli.deploy import (
@@ -506,8 +507,6 @@ def publish(build, tag):
 
     deployed = {}
 
-    command = "arkitekt run port"
-
     docker_run = subprocess.run(["docker", "tag", build.build_id, tag])
     if docker_run.returncode != 0:
         raise click.ClickException("Could not retag docker container")
@@ -627,7 +626,7 @@ def stage(build, version=None):
         ],
     )
 
-    raise click.ClickException("Not implemented yet")
+    raise click.ClickException("Docker container exited")
 
 
 def prompt_scopes():
