@@ -24,7 +24,7 @@ class Manifest(BaseModel):
     author: str
     logo: Optional[str]
     entrypoint: str
-    command: Optional[str]
+    command: str = "arkitekt run port"
     scopes: List[str]
     requirements: List[Requirement] = Field(default_factory=list)
     created_at: datetime.datetime = Field(default_factory=datetime.datetime.now)
