@@ -4,7 +4,7 @@ from rekuest.actors.vars import current_assignation_helper
 
 class tqdm(tqdm):
     """A tqdm that reports progress to arkitekt through the
-    assignation context"""
+    assignation contexst"""
 
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
